@@ -482,7 +482,7 @@ class SpotifySearch(GObject.Object):
             @param storage_type as StorageType
             @return track_id
         """
-        track_id = payload["id"]
+        spotify_id = payload["id"]
         title = payload["name"]
         _artists = []
         for artist in payload["artists"]:
@@ -509,7 +509,7 @@ class SpotifySearch(GObject.Object):
         except:
             timestamp = None
             year = None
-        duration = payload["duration_ms"] // 1000
+        duration = payload["duration_ms"]
         cover_uri = payload["album"]["images"][0]["url"]
         uri = "web://%s" % payload["id"]
         mtime = int(time())
@@ -518,5 +518,5 @@ class SpotifySearch(GObject.Object):
                    album_name, album_id, uri, 0, 0,
                    0, 0, mtime, title, duration, tracknumber,
                    discnumber, discname, year, timestamp, mtime,
-                   0, 0, 0, 0, track_id, 0, storage_type)
+                   0, 0, 0, 0, spotify_id, 0, storage_type)
         return (album_id, track_id, cover_uri)
