@@ -346,13 +346,21 @@ class TagReader:
             year = timestamp = None
             for (exists, date) in [date_index, datetime_index]:
                 if exists:
-                    year = date.get_year()
-                    month = date.get_month()
-                    day = date.get_day()
-                    gst_datetime = Gst.DateTime.new_local_time(
-                        year, month, day, 0, 0, 0)
-                    glib_datetime = gst_datetime.to_g_date_time()
-                    timestamp = glib_datetime.to_unix()
+                    if date.has_year():
+                        year = date.get_year()
+                    if date.has_month():
+                        month = date.get_month()
+                    else:
+                        month = 1
+                    if date.has_day():
+                        day = date.get_day()
+                    else:
+                        day = 1
+                    if year is not None:
+                        gst_datetime = Gst.DateTime.new_local_time(
+                            year, month, day, 0, 0, 0)
+                        glib_datetime = gst_datetime.to_g_date_time()
+                        timestamp = glib_datetime.to_unix()
             return (year, timestamp)
         except Exception as e:
             Logger.error("TagReader::get_year(): %s", e)
